<?php

/**
 * @file
 * Checkout pane callback functions for the gift aid module.
 */

/**
 * Checkout pane callback: returns the customer profile pane's settings form.
 */
function commerce_giftaid_pane_settings_form($checkout_pane) {
  $form = array();

  $form['commerce_giftaid_pane'] = array(
    '#type' => 'textarea',
    '#title' => t('Giftaid declaration'),
    '#description' => t('Specify the gift aid declaration the user can tick to agree to.'),
    '#default_value' => _commerce_giftaid_get_declaration(),
  );

  return $form;
}


/**
 * Checkout pane callback: returns a giftaid edit form if the order
 * has items which are eligable for gift aid.
 */
function commerce_giftaid_pane_checkout_form($form, &$form_state, $checkout_pane, $order) {
  if (commerce_giftaid_order_contains_eligable_items($order)) {
    $giftaid_form['commerce_giftaid'] = array(
      '#type' => 'checkbox',
      '#title' => _commerce_giftaid_get_declaration(),
      '#default_value' => isset($order->data['commerce_giftaid']) ? $order->data['commerce_giftaid'] : 0,
    );

    return $giftaid_form;
  }
}

/**
 * Checkout pane callback: validates a giftaid edit form.
 */
function commerce_giftaid_pane_checkout_form_validate($form, &$form_state, $checkout_pane, $order) {
  $value = $form_state['values']['commerce_giftaid_pane']['commerce_giftaid'];
  if (!in_array($value, array(0, 1))) {
    return FALSE;
  }
  return TRUE;
}

/**
 * Checkout pane callback: submits a giftaid edit form.
 */
function commerce_giftaid_pane_checkout_form_submit($form, &$form_state, $checkout_pane, $order) {
  $values = $form_state['values'];
  if (isset($values['commerce_giftaid_pane'])) {
    $order->data['commerce_giftaid'] = $values['commerce_giftaid_pane']['commerce_giftaid'];
    _commerce_giftaid_set_giftaid_order($order, TRUE);
  }
}

/**
 * Checkout pane callback: returns the cart contents review data for the
 *   Review checkout pane.
 */
function commerce_giftaid_pane_review($form, $form_state, $checkout_pane, $order) {
  if (isset($order->data['commerce_giftaid'])) {
    return $order->data['commerce_giftaid'] ? t('Gift aid declaration accepted') : t('Gift aid declaration not accepted');
  }
}

/**
 * @return string
 *   The current gift aid declarion for the site or the default one.
 */
function _commerce_giftaid_get_declaration() {
  return variable_get('commerce_giftaid_pane', t('I confirm I have paid or will pay an amount of Income Tax and/or Capital Gains Tax for the current tax year (6 April to 5 April) that is at least equal to the amount of tax that all the charities and Community Amateur Sports Clubs (CASCs) that I donate to will reclaim on my gifts for the current tax year. I understand that other taxes such as VAT and Council Tax do not qualify. I understand the charity will reclaim 25p of tax on every £1 that I have given.'));
}
